Change Log
===========

0.0.6
------
- Improved inline help

0.0.5
------
- Initial inline help

0.0.4
------
- Added token operations methods (create, list, extend, and delete)
- Added position history w/ filtering options
- Added trade history w/ filtering options
- Added position history w/ filtering options
- Misc improvements and bug fixes

0.0.3
------
- Added strategy operations methods
- Added orders operations methods
- Enhanced account operations
- Misc bug fixes

0.0.2
------
- First release. Includes basic functionality

0.0.1
------
- No code. Just a placeholder for pypi
